1
0
mirror of https://git.yoctoproject.org/poky synced 2026-05-09 05:29:32 +00:00

vulkan: upgrade 1.3.290.0 -> 1.3.296.0

(From OE-Core rev: 5e00171e154d0c5e096efc594008e09228b25cfa)

Signed-off-by: Alexander Kanavin <alex@linutronix.de>
Signed-off-by: Richard Purdie <richard.purdie@linuxfoundation.org>
This commit is contained in:
Alexander Kanavin
2024-11-25 13:01:23 +01:00
committed by Richard Purdie
parent 9b497d8bba
commit 7cf8869051
9 changed files with 11 additions and 55 deletions
@@ -4,7 +4,7 @@ HOMEPAGE = "https://www.khronos.org/registry/spir-v"
LICENSE = "MIT"
LIC_FILES_CHKSUM = "file://LICENSE;md5=d14ee3b13f42e9c9674acc5925c3d741"
SRCREV = "2acb319af38d43be3ea76bfabf3998e5281d8d12"
SRCREV = "2a9b6f951c7d6b04b6c21fe1bf3f475b68b84801"
SRC_URI = "git://github.com/KhronosGroup/SPIRV-Headers;protocol=https;branch=main"
PE = "1"
# These recipes need to be updated in lockstep with each other:
@@ -1,43 +0,0 @@
From 39b6385454d705128e684ed779ba9620e2ead1e2 Mon Sep 17 00:00:00 2001
From: Yoann Congal <yoann.congal@smile.fr>
Date: Thu, 1 Aug 2024 18:58:04 +0200
Subject: [PATCH] update_build_version.py: support an envvar to force the
description
FORCED_BUILD_VERSION_DESCRIPTION envvar can be used to force a version
description instead of resorting to git describe which can change for a
given commit if multiple lightweight commits point ot it.
Signed-off-by: Yoann Congal <yoann.congal@smile.fr>
Upstream-Status: Backport [https://github.com/KhronosGroup/SPIRV-Tools/commit/bc4060ed274ad9749c20daced96d6f0518d6418e]
---
utils/update_build_version.py | 9 +++++----
1 file changed, 5 insertions(+), 4 deletions(-)
diff --git a/utils/update_build_version.py b/utils/update_build_version.py
index bb66e18a..9115cab1 100755
--- a/utils/update_build_version.py
+++ b/utils/update_build_version.py
@@ -24,9 +24,10 @@
# - The software version deduced from the given CHANGES file.
# - A longer string with the project name, the software version number, and
# git commit information for the CHANGES file's directory. The commit
# information is the output of "git describe" if that succeeds, or "git
# rev-parse HEAD" if that succeeds, or otherwise a message containing the
# phrase "unknown hash".
# The string contents are escaped as necessary.
import datetime
@@ -150,7 +151,7 @@ def main():
sys.exit(1)
repo_path = os.path.dirname(changes_file_path)
- description = describe(repo_path)
+ description = os.getenv("FORCED_BUILD_VERSION_DESCRIPTION", describe(repo_path))
content = OUTPUT_FORMAT.format(version_tag=version, description=description)
# Escape file content.
@@ -7,9 +7,8 @@ SECTION = "graphics"
LICENSE = "Apache-2.0"
LIC_FILES_CHKSUM = "file://LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57"
SRCREV = "0cfe9e7219148716dfd30b37f4d21753f098707a"
SRCREV = "6dcc7e350a0b9871a825414d42329e44b0eb8109"
SRC_URI = "git://github.com/KhronosGroup/SPIRV-Tools.git;branch=main;protocol=https \
file://0001-update_build_version.py-support-an-envvar-to-force-t.patch \
"
PE = "1"
# These recipes need to be updated in lockstep with each other:
@@ -11,7 +11,7 @@ LICENSE = "Apache-2.0 & MIT"
LIC_FILES_CHKSUM = "file://LICENSE.md;md5=1bc355d8c4196f774c8b87ed1a8dd625"
SRC_URI = "git://github.com/KhronosGroup/Vulkan-Headers.git;branch=main;protocol=https"
SRCREV = "b379292b2ab6df5771ba9870d53cf8b2c9295daf"
SRCREV = "29f979ee5aa58b7b005f805ea8df7a855c39ff37"
S = "${WORKDIR}/git"
@@ -9,8 +9,8 @@ SECTION = "libs"
LICENSE = "Apache-2.0"
LIC_FILES_CHKSUM = "file://LICENSE.txt;md5=7dbefed23242760aa3475ee42801c5ac"
SRC_URI = "git://github.com/KhronosGroup/Vulkan-Loader.git;branch=main;protocol=https"
SRCREV = "40b8e6eeead809a62c708cb48fdd9f8f2eab3f15"
SRC_URI = "git://github.com/KhronosGroup/Vulkan-Loader.git;branch=vulkan-sdk-1.3.296;protocol=https"
SRCREV = "7aeb5e4324957b6f60dac5c8cedb955df4fecbfb"
S = "${WORKDIR}/git"
@@ -6,8 +6,8 @@ SECTION = "libs"
LICENSE = "Apache-2.0"
LIC_FILES_CHKSUM = "file://LICENSE.txt;md5=3b83ef96387f14655fc854ddc3c6bd57"
SRC_URI = "git://github.com/KhronosGroup/Vulkan-Tools.git;branch=main;protocol=https"
SRCREV = "53a6ba7c235cbe0b0f3e85e3de6d9070bcfec710"
SRC_URI = "git://github.com/KhronosGroup/Vulkan-Tools.git;branch=vulkan-sdk-1.3.296;protocol=https"
SRCREV = "74dd90abd69f813220b572e1d89c17bc7784972d"
S = "${WORKDIR}/git"
@@ -10,7 +10,7 @@ LICENSE = "Apache-2.0"
LIC_FILES_CHKSUM = "file://LICENSE.md;md5=4ca2d6799091aaa98a8520f1b793939b"
SRC_URI = "git://github.com/KhronosGroup/Vulkan-Utility-Libraries.git;branch=main;protocol=https"
SRCREV = "5f26cf65a18bc89a8e3d6569c14314b6fdac8d4d"
SRCREV = "0a786ee3e4fd3602f68ff0ffd9fdcb12e0efb646"
S = "${WORKDIR}/git"
@@ -8,8 +8,8 @@ SECTION = "libs"
LICENSE = "Apache-2.0 & MIT"
LIC_FILES_CHKSUM = "file://LICENSE.txt;md5=cd3c0bc366cd9b6a906e22f0bcb5910f"
SRC_URI = "git://github.com/KhronosGroup/Vulkan-ValidationLayers.git;branch=vulkan-sdk-1.3.290;protocol=https"
SRCREV = "a92629196a4fed15e59c74aa965dd47bd5ece3b7"
SRC_URI = "git://github.com/KhronosGroup/Vulkan-ValidationLayers.git;branch=vulkan-sdk-1.3.296;protocol=https"
SRCREV = "9935cdd6f9524b1da1e140393fa69a0a1b72125d"
S = "${WORKDIR}/git"
@@ -10,7 +10,7 @@ LICENSE = "MIT"
LIC_FILES_CHKSUM = "file://LICENSE.md;md5=12e6af3a0e2a5e5dbf7796aa82b64626"
SRC_URI = "git://github.com/zeux/volk.git;branch=master;protocol=https"
SRCREV = "466085407d5d2f50583fd663c1d65f93a7709d3e"
@@ -24,9 +24,10 @@
# - A longer string with the project name, the software version number, and
# git commit information for the CHANGES file's directory. The commit
-# information is the output of "git describe" if that succeeds, or "git
-# rev-parse HEAD" if that succeeds, or otherwise a message containing the
-# phrase "unknown hash".
+# information is the content of the FORCED_BUILD_VERSION_DESCRIPTION
+# environement variable is it exists, else the output of "git describe" if
+# that succeeds, or "git rev-parse HEAD" if that succeeds, or otherwise a
+# message containing the phrase "unknown hash".
# The string contents are escaped as necessary.
import datetime
SRCREV = "59d26900f53c7621a8ba8ab0e3f18d3bd883fa9a"
S = "${WORKDIR}/git"